# -*- coding: utf-8 -*-
import ogr, os, sys
from osgeo.gdalconst import * # chargement des constantes : pour GA_ReadOnly

os.chdir('.')
driver = ogr.GetDriverByName('ESRI Shapefile')

# ouverture du fichier d'entree
velosDS = driver.Open('supports-velos.shp', GA_ReadOnly)
if velosDS is None:
  print('Could not open file')
  sys.exit(1)
velosLayer = velosDS.GetLayer()

#Q1) nombre de stations à Rennes (1 station = 1 feature)

nb_stations=0
for velosstop in velosLayer:
    if velosstop.GetField('nom_commune')=="Rennes":
        nb_stations += 1

print("nombre de stations:", nb_stations)

#Q2) nombre de supports à Rennes
velosLayer.ResetReading()
cnt = 0
for velosstop in velosLayer:
    if velosstop.GetField('nom_commune')=="Rennes":
        nbsup=velosstop.GetField('nombre_supp')
        cnt += nbsup
print("Il y a " + str(cnt) + " supports de vélos à Rennes.")

#Q3) combien stations de vélo avec plus de 10 supports
velosLayer.ResetReading()
nb_stations=0
for velosstop in velosLayer:
    if velosstop.GetField('nom_commune')=="Rennes" and velosstop.GetField('nombre_supp')>=10:
        nb_stations += 1
print("nombre de stations >10:", nb_stations)

#Q4) rues avec support vélo : solution 1 avec affichage en ligne (pas éléguant)
velosLayer.ResetReading()
for velosstop in velosLayer:
    if velosstop.GetField('nom_commune')=="Rennes":
        voie = velosstop.GetField("nom_voie")
        print(voie)
        
#autre solution utilisant une liste de voies
velosLayer.ResetReading()
liste_voies = []
for velosstop in velosLayer:
    if velosstop.GetField('nom_commune')=="Rennes":
        voie = velosstop.GetField("nom_voie")
        liste_voies.append( voie )

#exemple pour supprimer les doublons:
liste_voies = list( set(liste_voies) )
liste_voies.sort()

print(liste_voies)

#Q5) Infos sur une station

#idstation = input("station?")
idstation = 45
stationfeature= velosLayer.GetFeature( idstation )

print("Coordonnées spatiales:" + str(stationfeature.GetGeometryRef())
print("nombre de supports:" + str(stationfeature.GetField('nombre_supp'))

#Q6) 
# Identification d'une station par son identifiant (solution manuelle)
idstation = 258
for velosstop in velosLayer:
    if velosstop.GetField('objectid')==idstation:
        stationfeature=velosstop
        break #arrête la recherche
        
# ou avec utilisation des filtres
velosLayer.SetAttributeFilter("objectid="+str(idstation))
stationfeature = velosLayer.GetNextFeature()
velosLayer.SetAttributeFilter("")
velosLayer.ResetReading()

#affichage des information sur la station
print( stationfeature.GetField("nom_voie") )
geom = stationfeature.GetGeometryRef()
print(geom)

#recherche de la station la plus proche
feature_plusproche = None
plusCourteDistance = float("inf")
for f in velosLayer :
    if f.GetField("objectid") == stationfeature.GetField("objectid"):
        continue
    #1. calculer la distance d entre f et feature
    geomf = f.GetGeometryRef()
    d = (geom.GetX() - geomf.GetX())**2 + (geom.GetY() - geomf.GetY())**2
    #2. regarder si d est plus petit que plusCourteDistance
    if d < plusCourteDistance:
        #3. si oui, f devient le plus proche !
        feature_plusproche = f
        plusCourteDistance = d

print(feature_plusproche.GetGeometryRef())
print(feature_plusproche.GetField("nom_voie"))












