#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Oct 16 08:59:58 2019

@author: tguyet
"""

import ogr, os, sys
from osgeo.gdalconst import GA_ReadOnly # chargement des constantes : pour GA_ReadOnly


def grignoter(parcelles, g):
    """
    - parcelles: liste de geometries
    - g: une geometrie
    - retourne une liste de geometries
    
    La fonction grignote chaque geometrie de parcelles avec la geometrie g et retourne la liste des géométries modifiées.
    Si une géométrie est vide par le grignotage, alors elle est supprimée de la liste
    """
    plist=[]
    for p in parcelles:
        np = p.Difference(g)
        if not np.Empty():
            plist.append( p.Difference(g) )
    return plist

################

os.chdir('/home/tguyet/Enseignements/2019-2020/TELENVI/ProgSIG/CM2/EtudeTampon')
driver = ogr.GetDriverByName('ESRI Shapefile')


def surfaceperdue(codepostal, distance):
    # ouverture du fichier d'entree
    DSparcelles = driver.Open('ILOTS_SIMPLES.shp', GA_ReadOnly)
    if DSparcelles is None:
      print('Could not open file')
      sys.exit(1)
    parcelles = DSparcelles.GetLayer()
    
    DScommunes = driver.Open('Cadastre/'+str(codepostal)+'/COMMUNE_id.shp', GA_ReadOnly)
    if DScommunes is None:
      print('Could not open file')
      sys.exit(1)
    communes = DScommunes.GetLayer()
    
    ## Warning: il faut obligatoirement écrire en deux lignes l'opération suivante
    featcomm = communes.GetFeature(0)
    geomcomm = featcomm.GetGeometryRef()
    
    parcelles.SetSpatialFilter ( geomcomm )
    parcellist=[]
    
    areacomm=0 ## surface des parcelles agricoles de la commune
    for p in parcelles:
        ## !!! ATTENTION !!! sans le clone ... cela provoque une très grosse erreur difficilement compréhensible
        geomP = p.GetGeometryRef().Clone()
        areacomm += geomP.GetArea()
        parcellist.append( geomP )
    
    # Fermeture des sources de donnees (on peut fermer ici, grâce au Clone)
    DSparcelles.Destroy()
    DScommunes.Destroy()
        
    DSbatis = driver.Open('Cadastre/'+str(codepostal)+'/BATIMENT_id.shp', GA_ReadOnly)
    if DSbatis is None:
      print('Could not open file')
      sys.exit(1)
    batis = DSbatis.GetLayer()
    
    for b in batis:
        geomB = b.GetGeometryRef()
        buffer = geomB.Buffer(distance)
        parcellist = grignoter( parcellist, buffer )
    DSbatis.Destroy()
    
    area=0 ## surface des parcelles agricoles perdues
    for p in parcellist:
        area += p.GetArea()
        p.Destroy() ### Du fait de l'utilisation du Clone, il faut "nettoyer" les géométries
    parcellist.clear()
    return (areacomm,area)

cp = 35027
d= 150
(areacomm,area) = surfaceperdue(cp, d)
print("Surface perdue avec une distance %dm: %dha (%.2f%%)"%(d, (areacomm-area)/100, 100*float(areacomm-area)/float(areacomm)) )

