#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example to cluster a satellite image time series (SITS) to a dataset of time series.

This script shows how to transform SITS to dataset of time series. 
Then, its applies a data mining technique (time series clustering).
Finally, it shows how to save to result of the time series clustering into a gtiff image.

@author: Thomas Guyet (thomas.guyet@irisa.fr)
"""


import os
import gdal
import numpy as np
import matplotlib.pyplot as plt
from sklearn.cluster import KMeans, DBSCAN
from random import randint
from sklearn.preprocessing import StandardScaler

showimages=0

os.chdir('/home/tguyet/Enseignements/2019-2020/TELENVI/ProgSIG/CM6')
dataset = gdal.Open("Senegal_Diourbel_NDVI_2002.tif", 0 )

bands=[]
for i in range(dataset.RasterCount):
    band=dataset.GetRasterBand(i+1)
    bands.append( band.ReadAsArray() )
data=np.array(bands)
#nettoyage des variables inutiles)
del(bands,band,i)

if showimages:
	print(np.shape(data)) #output: (23, 261, 499)
	
	## Affichage d'une bande de l'image (ici, la 13eme date)
	plt.figure()
	plt.imshow(data[12,:,:])

## transformation des 23 couches de matrice 2D, en matrice 2D de pixels de dimension 23

data = np.dstack(data)

if showimages:
	print(np.shape(data)) #output: (261, 499, 23)
	
	## Affichage d'une composition colorée à partir des bandes 0 à 3 de l'image
	plt.figure()
	plt.imshow(data[:,:,0:3])

## transformation en vecteurs de séries temporelles
tsdata = data.reshape( (data.shape[0]*data.shape[1],data.shape[2]) )

if showimages:
	print(np.shape(tsdata)) #output: (130239, 23)
	## Affichage d'une série temporelle du jeu de données
	plt.figure()
	plt.plot(tsdata[230])

#######################  TIME SERIES PROCESSING ################
	

clusterer = KMeans(n_clusters=5, random_state=0)
trainsize=1000
trainset = tsdata[ [randint(0,tsdata.shape[0]) for i in range(trainsize)] ]	

clusters = clusterer.fit(trainset)
clusters = clusterer.predict(tsdata)

#clusters = clusterer.fit_predict(tsdata)
#######################  image saving ################
clusters = clusters.reshape( (data.shape[0], data.shape[1]) )
if showimages:
	## Affichage de l'image résultant du clustering
	plt.figure()
	plt.imshow(clusters)

## enregistrement de l'image (version bourrine)
driver = gdal.GetDriverByName( "GTiff" )
dst_ds = driver .Create( "output.tif", data.shape[1], data.shape[0], 1, gdal.GDT_Int32 )
dst_ds.SetProjection( dataset.GetProjection() )
dst_ds.SetGeoTransform( dataset.GetGeoTransform() )
dst_ds.GetRasterBand(1).WriteArray( clusters )
dst_ds=None


