#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example to cluster a satellite image time series (SITS) to a dataset of time series.

This script shows how to transform SITS to dataset of time series. 
Then, its applies a data mining technique (time series clustering).
Finally, it shows how to save to result of the time series clustering into a gtiff image.

@author: Thomas Guyet (thomas.guyet@irisa.fr)
"""


import os
import gdal
import numpy as np
from sklearn.cluster import KMeans, DBSCAN
from random import randint
from sklearn.preprocessing import StandardScaler
from sklearn.metrics import confusion_matrix


os.chdir('/home/tguyet/Enseignements/2019-2020/TELENVI/ProgSIG/CM6')
dataset = gdal.Open("Senegal_Diourbel_NDVI_2002.tif", 0 )

bands=[]
for i in range(dataset.RasterCount):
    band=dataset.GetRasterBand(i+1)
    bands.append( band.ReadAsArray() )
data=np.array(bands)
#nettoyage des variables inutiles)
del(bands,band,i)

## transformation des 23 couches de matrice 2D, en matrice 2D de pixels de dimension 23
data = np.dstack(data)
	
def classification(d, n, trainsize =1000):
	## transformation en vecteurs de séries temporelles
	tsdata = data.reshape( (d.shape[0]*d.shape[1],d.shape[2]) )
	clusterer = KMeans(n_clusters=n)
	trainset = tsdata[ [randint(0,tsdata.shape[0]) for i in range(trainsize)] ]	
	clusters = clusterer.fit(trainset)
	clusters = clusterer.predict(tsdata)
	return clusters #.reshape( (d.shape[0], d.shape[1]) )

classif1 = classification(data, 3)
classif2 = classification(data, 3)

m=confusion_matrix(classif1, classif2)
print(m)
