#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Example to cluster a satellite image time series (SITS) to a dataset of time series.

This script shows how to transform SITS to dataset of time series. 
Then, its applies a data mining technique (time series clustering).
Finally, it shows how to save to result of the time series clustering into a gtiff image.

@author: Thomas Guyet (thomas.guyet@irisa.fr)
"""


import os
import gdal
import numpy as np
import matplotlib.pyplot as plt
from sklearn.cluster import KMeans, DBSCAN
from random import randint
from sklearn.preprocessing import StandardScaler

showimages=0

os.chdir('/home/tguyet/Enseignements/2019-2020/TELENVI/ProgSIG/CM6')
dataset = gdal.Open("Senegal_Diourbel_NDVI_2002.tif", 0 )

bands=[]
for i in range(dataset.RasterCount):
    band=dataset.GetRasterBand(i+1)
    bands.append( band.ReadAsArray() )
data=np.array(bands)
#nettoyage des variables inutiles)
del(bands,band,i)

## transformation des 23 couches de matrice 2D, en matrice 2D de pixels de dimension 23

data = np.dstack(data)

## transformation en vecteurs de séries temporelles
tsdata = data.reshape( (data.shape[0]*data.shape[1],data.shape[2]) )

#######################  TIME SERIES PROCESSING ################

def classif(d, n, trainsize=1000):
	clusterer = KMeans(n_clusters=n)
	trainset = d[ [randint(0,d.shape[0]-1) for i in range(trainsize)] ]	
	clusters = clusterer.fit(trainset)
	clusters = clusterer.predict(d)
	return clusters

from sklearn.metrics import confusion_matrix
from sklearn.metrics import cohen_kappa_score

mk=[]
for nb in [100,1000,10000,100000]:
	kappas=[]
	for it in range(10):
		c1 = classif(tsdata, 5, nb)
		c2 = classif(tsdata, 5, nb)
		
		#m=confusion_matrix(c1,c2)
		#print(m)
		k=cohen_kappa_score(c1,c2)
		#print(k)
		kappas.append(k)
	
	#print(np.mean(kappas), np.std(kappas))
	mk.append(np.mean(kappas))
print(mk)
	













