
#import des librairies
import os

import sys
import gdal
import ogr
from gdalconst import GA_ReadOnly
import pandas as pd
import numpy as np


dsz = gdal.Open('zone1.tif', GA_ReadOnly)
if dsz is None:
    print('Could not open image')
    
projection = dsz.GetGCPProjection()
geotransform = dsz.GetGeoTransform()

bands = np.array([dsz.GetRasterBand(i+1).ReadAsArray() for i in range(dsz.RasterCount)])

###############   Definition des ROI   ######################
driver = ogr.GetDriverByName('ESRI Shapefile')
inDS = driver.Open('sample.shp', 0)
layer = inDS.GetLayer()

driver = gdal.GetDriverByName('MEM')  # In memory dataset
target_ds = driver.Create('', dsz.RasterXSize, dsz.RasterYSize, 1, gdal.GDT_Float32)
target_ds.SetGeoTransform(geotransform)
target_ds.SetProjection(projection)

band = target_ds.GetRasterBand(1)
band.Fill(-1)

gdal.RasterizeLayer(target_ds, [1], layer, burn_values=[0], options=["ATTRIBUTE=cl"])
labeled_pixels = target_ds.GetRasterBand(1).ReadAsArray()

######## Reshape #####
img = np.dstack(bands)
Xall = img.reshape( (img.shape[0]*img.shape[1], img.shape[2]) )
yall = labeled_pixels.ravel() # aplatis un array sur une seule dimension

######## Sélection des pixels labelisés ######
X = Xall[yall!=-1]
y = yall[yall!=-1]


########## Classification #########

from sklearn.tree import DecisionTreeClassifier
clf = DecisionTreeClassifier(min_samples_leaf=7)
clf.fit(X, y)


########### Reconstruction de l'image #########
yp=clf.predict(Xall)
yf=(yall==-1)*yall+(yall!=-1)*yp

img_cl = yf.reshape((img.shape[0],img.shape[1]))

import matplotlib.pyplot as plt

plt.imshow(img_cl)


